<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

// Hook to add the sidebar menu
add_action('admin_menu', 'fmts_add_admin_menu');
function fmts_add_admin_menu() {
    // Add a new top-level menu named "FormToss"
    add_submenu_page(
        'wpcf7',
        __('Form To SS Settings', 'form-to-ss'),
        __('FormToSS', 'form-to-ss'),
        'manage_options',
        'formtoss-api-settings',
        'fmts_settings_page',
        10 //  position
    );
}

function fmts_settings_page() {
    // Get the global API key for the user
    $api_key = get_option( 'formtoss_auth_key', '');
    $status = get_option( 'formtoss_auth_status', 0);


    // Check if the current user is an admin
    $is_admin = current_user_can('manage_options');

    // Retrieve the message stored in the transient
    $error_message = get_transient('fmts_form_error_message');
    $success_message = get_transient('fmts_form_success_message');
    ?>

    <div class="wrap">
        <h1>FormToSS Settings</h1>

        <fieldset>
            <?php if ($is_admin): ?>
            <form method="post" action="<?php echo esc_url( admin_url('admin-post.php') ); ?>">
                <?php wp_nonce_field('manage_formtoss_api_key', 'formtoss_nonce_api'); ?>

            <div style="width: 50%; margin-top: 10px">
                <label for="formtoss_auth_key"><?php echo esc_html(fmts_get_translation('API Key')); ?></label>
                <div style="display: flex; align-items: center; gap: 10px">
                    <input type="text" id="formtoss_auth_key" name="formtoss_auth_key"
                           value="<?php echo esc_textarea($api_key); ?>"
                           class="large-text form-field"  <?php echo !empty($api_key) ? 'disabled' : ''; ?>>

                    <?php if (!empty($api_key) ) : ?>
                    <button type="button" class="edit-form-btn"  data-target="#formtoss_auth_key"
                            style="color: white; background-color: black; border: none; width: 50px;  border-radius: 10%; padding-top: 5px; padding-bottom: 5px; cursor: pointer;">
                        <?php echo esc_html(fmts_get_translation('Edit')); ?>
                    </button>
                    <a href="#" class="reset-form" data-reset="true"  style="color: red; text-decoration: none;  cursor: pointer;">Reset</a>
                        <input type="hidden" name="reset" value="0" id="reset_flag">
                    <?php endif; ?>
                </div>
            </div>
                <!-- Status -->
                <div style="color: <?php echo $status == 1 ? 'seagreen' : 'red'; ?>; margin-top: 5px; font-size: medium">
                    <?php echo $status == 1 ? '● Activated' : '● Deactivated'; ?>
                </div>

                <p style="color: red;"><?php echo wp_kses_post($error_message); ?></p>
                <p style="color: green;"><?php echo wp_kses_post($success_message); ?></p>

                <input type="hidden" name="action" value="save_formtoss_auth_key">
                <button type="submit" id="submit_button"  class="button button-primary" <?php echo !empty($api_key) ? 'disabled' : ''; ?> style="margin-top: 10px;">
                    Save
                </button>
            </form>

            <?php else: ?>
                <div style="width: 50%; margin-top: 10px">
                    <label><?php echo esc_html(fmts_get_translation('API Key')); ?></label>
                    <div style="display: flex; align-items: center; gap: 10px">
                        <input type="text" value="*********************************************"
                               class="large-text" disabled>
                    </div>
                </div>

                <!-- Status -->
                <div style="color: <?php echo $status == 1 ? 'seagreen' : 'red'; ?>; margin-top: 5px; font-size: medium">
                    <?php echo $status == 1 ? '● ' . esc_html(fmts_get_translation('Activate')) : '● '. esc_html(fmts_get_translation('Deactivate')); ?>
                </div>

                <!--            Non Admin message-->
                <div style="color: red">
                    <p><?php echo esc_html(fmts_get_translation('Non Admin Message 1')); ?> <br> <?php echo esc_html(fmts_get_translation('Non Admin Message 2')); ?></p>
                </div>

            <?php endif; ?>
        </fieldset>
    </div>
    <?php
}

// Hook to handle the form submission
add_action('admin_post_save_formtoss_auth_key', 'fmts_save_auth_key');
function fmts_save_auth_key()
{
    if (!isset($_POST['formtoss_nonce_api']) || !wp_verify_nonce(sanitize_text_field( wp_unslash( $_POST['formtoss_nonce_api'] ) ), 'manage_formtoss_api_key')) {
        wp_die('Invalid nonce');
    }

    // Ensure user has permission to manage options
    if (!current_user_can('manage_options')) {
        wp_die('Unauthorized user');
    }

    // Get the API key from the form
    $api_key = fmts_get_sanitized_text( $_POST, 'formtoss_auth_key', '' );

    // Validate the input fields
    if (empty($api_key) and isset($_POST['reset'])) {
        update_option( 'formtoss_auth_key', '');
        update_option('formtoss_auth_status', 0);
        delete_transient('fmts_form_error_message');
        set_transient('fmts_form_success_message',  esc_html(fmts_get_translation('API Key is Deleted')), 30);
        fmts_redirect_to_referer_or();
    }
    if (empty($api_key) ){
        delete_transient('fmts_form_success_message');
        set_transient('fmts_form_error_message', esc_html(fmts_get_translation('API Key is required')), 30);

        // Redirect back to the settings page with an error
        fmts_redirect_to_referer_or();
    }

    $domain_name = fmts_get_sanitized_text( $_SERVER, 'HTTP_HOST', '' );

    // Prepare data for the external API call
    $apiUrl = FMTS_API_BASE_URL .'/api/api_validation_check';

        $response = wp_remote_post($apiUrl, array(
            'method'    => 'POST',
            'timeout'   => 45,
            'body'      => array(
                'api_key'   => $api_key,
                'domain'    => $domain_name,
            ),
        ));

        // Check if the API response is valid
        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            delete_transient('fmts_form_success_message');
            set_transient('fmts_form_error_message', "Something went wrong: $error_message", 30);
            fmts_redirect_to_referer_or();
        }

        $response_body = wp_remote_retrieve_body($response);
        $data = json_decode($response_body, true);

        if (isset($data['message']) && $data['message'] === 'Form ID and API key are valid') {
            update_option('formtoss_auth_key', $api_key);
            update_option('formtoss_auth_status', 1);
            delete_transient('fmts_form_error_message');
            set_transient('fmts_form_success_message', esc_html(fmts_get_translation('API Key saved and validated successfully')), 30);
        }elseif (isset($data['message']) && $data['message'] === 'Already saved'){
            update_option('formtoss_auth_key', $api_key);
            update_option('formtoss_auth_status', 1);
            delete_transient('fmts_form_success_message');
            set_transient('fmts_form_error_message', esc_html(fmts_get_translation('API Key already validated')), 30);
        }elseif (isset($data['message']) && $data['message'] === 'Cannot create more than one domain'){
            delete_transient('fmts_form_success_message');
            set_transient('fmts_form_error_message', esc_html(fmts_get_translation('Cannot create more than one domain')), 30);
        }elseif (isset($data['message']) && $data['message'] === 'updated your domain'){
            update_option('formtoss_auth_key', $api_key);
            update_option('formtoss_auth_status', 1);
            delete_transient('fmts_form_error_message');
            set_transient('fmts_form_success_message', esc_html(fmts_get_translation('API Key saved and validated successfully')), 30);
        } else {
            delete_transient('fmts_form_success_message');
            set_transient('fmts_form_error_message', esc_html(fmts_get_translation('API Key validation failed')), 30);
        }

        // Redirect back to the settings page
        fmts_redirect_to_referer_or();
}


