<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

add_filter('wpcf7_editor_panels', function ($panels) {
    $panels['formtoss_form_id'] = array(
        'title' => 'FormToSS',
        'callback' => 'fmts_editor_panel_form_id_settings'
    );
    return $panels;
}, 10, 1);

function fmts_editor_panel_form_id_settings($post) {
    $desc_link = wpcf7_link(
        FMTS_API_BASE_URL,
        fmts_get_translation('About Form Id And API Key'),
        array('target' => '_blank')
    );
    $description = fmts_get_translation('Description_One') . ' ' . $desc_link . ' ' . fmts_get_translation('Description_Two');
    $form_id = get_post_meta($post->id(), 'formtoss_form_id', true);
    $status = get_post_meta($post->id(), 'status', true);

    $contact_form_id = $post->id();
    // Check if the current user is an admin
    $is_admin = current_user_can('manage_options');

    // Retrieve the message stored in the transient
    $error_messages = get_transient('fmts_form_error_messages'. $contact_form_id);
    $success_messages = get_transient('fmts_form_success_messages'. $contact_form_id);
    //$confirm_texts = get_transient('Are you sure to reset the Form ID');
    ?>

    <h2><?php echo esc_html(fmts_get_translation('Form ID Settings')); ?></h2>
    <fieldset>
        <legend><?php echo esc_html( fmts_get_translation('Information') ); ?></legend>
        <legend><?php echo wp_kses_post($description); ?></legend>

        <?php if ($is_admin): ?>
            <?php wp_nonce_field('manage_formtoss_connect_key', 'formtoss_nonce'); ?>
            <div style="width: 50%; margin-top: 10px">
                <label for="wpcf7-formtoss-form-id"><?php echo esc_html(fmts_get_translation('Form ID')); ?></label>
                <div  style="display: flex; align-items: center; gap: 10px">
                    <input type="text" id="wpcf7-formtoss-form-id" name="wpcf7-formtoss-form-id"
                           value="<?php echo esc_textarea($form_id); ?>"
                           class="large-text form-field"  <?php echo !empty($form_id) ? 'disabled' : ''; ?>>

                    <?php if (!empty($form_id) ) : ?>
                        <button type="button" class="edit-form-btn"  data-target="#wpcf7-formtoss-form-id"
                                style="color: white; background-color: black; border: none; width: 50px;  border-radius: 10%; padding-top: 5px; padding-bottom: 5px; cursor: pointer;">
                            <?php echo esc_html(fmts_get_translation('Edit')); ?>
                        </button>
                        <a href="#" class="reset-form" data-reset="true"  style="color: red; text-decoration: none;  cursor: pointer;">Reset</a>
                        <input type="hidden" name="reset" value="0" id="reset_flag">
                    <?php endif; ?>
                </div>
            </div>

            <p style="color: red;"><?php echo wp_kses_post($error_messages); ?></p>
            <p style="color: green;"><?php echo wp_kses_post($success_messages); ?></p>

            <!--  script for the edit button:-->
            <!--<script>
            jQuery(document).ready(function($) {
                $('.edit-form-btn').on('click', function() {
                    var targetField = $(this).data('target');
                    $(targetField).prop('disabled', false);
                });
                $('.reset-form').on('click', function() {
                    $('#reset_flag').val('1');
                    var confirmText = '<?php /*echo esc_js($confirm_texts); */?>';
                    if (confirm( confirmText)) {
                        $('#wpcf7-formtoss-form-id').val('');
                    }
                });
            });
        </script>-->

        <?php else: ?>

            <div style="width: 50%; margin-top: 10px">
                <label for="wpcf7-formtoss-form-id"><?php echo esc_html(fmts_get_translation('Form ID')); ?></label>
                <div  style="display: flex; align-items: center; gap: 10px">
                    <input type="text" id="wpcf7-formtoss-form-id" name="wpcf7-formtoss-form-id"
                           value="***************" class="large-text" disabled>
                </div>
            </div>
            <!-- Status -->
            <div style="color: <?php echo $status == 1 ? 'seagreen' : 'red'; ?>; margin-top: 5px; font-size: medium">
                <?php echo $status == 1 ? '● ' . esc_html(fmts_get_translation('Activate')) : '● '. esc_html(fmts_get_translation('Deactivate')); ?>
            </div>

            <!--            Non Admin message-->
            <div style="color: red">
                <p><?php echo esc_html(fmts_get_translation('Non Admin Message 1')); ?> <br> <?php echo esc_html(fmts_get_translation('Non Admin Message 2')); ?></p>

            </div>
        <?php endif; ?>
    </fieldset>
    <?php
}

//保存ボタン押下後のフック処理
function fmts_save_form_id_hook_panel_data($contact_form) {
    if ( ! isset( $_POST['formtoss_nonce'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['formtoss_nonce'] ) ), 'manage_formtoss_connect_key' ) ) {
        wp_die( '不正なリクエストです。' );
    }

    $is_admin = current_user_can('manage_options');

    if ($is_admin):
        // Retrieve previously saved  api_key if they exist
        $saved_formtoss_auth_key = get_option( 'formtoss_auth_key', true);
        $saved_form_id = get_post_meta($contact_form->id(), 'formtoss_form_id', true);

        $form_id = fmts_get_sanitized_text($_POST, 'wpcf7-formtoss-form-id', $saved_form_id);

        $api_key = fmts_get_sanitized_text($_POST, 'wpcf7-api_key', $saved_formtoss_auth_key);

        $domain_name = fmts_get_sanitized_text( $_SERVER, 'HTTP_HOST' );

        $reset_flag = fmts_get_sanitized_text( $_POST, 'reset', '0' );
        $contact_form_id = $contact_form->id();

        if ($reset_flag === '1') {
            update_post_meta($contact_form->id(), 'formtoss_form_id', '');  // Delete the form ID
            delete_transient('fmts_form_error_messages'. $contact_form_id);
            set_transient('fmts_form_success_messages' .$contact_form_id, esc_html(fmts_get_translation('Form ID is Deleted')), 30);

            fmts_redirect_to_referer_or();
        }

        // If only form_id is provided, save it without validation
        if (empty($form_id)){
            delete_transient('fmts_form_success_messages' .$contact_form_id);
            set_transient('fmts_form_error_messages' .$contact_form_id, esc_html(fmts_get_translation('Form ID is required')), 30);
            return;
        }

        // If only api_key is provided, save it without validation
        if (!empty($form_id) && empty($api_key)) {
            delete_transient('fmts_form_success_messages' .$contact_form_id);
            set_transient('fmts_form_error_messages' .$contact_form_id, esc_html(fmts_get_translation('setup the api key')), 30);
            return;
        }

        // Check if formtoss_form_id and api_key are provided
        if (!empty($form_id) && !empty($api_key)){
            // Make an API call to validate the form_id and api_key
            $apiUrl = FMTS_API_BASE_URL . '/api/api_validation_check';

            $response = wp_remote_post($apiUrl, array(
                'method'    => 'POST',
                'timeout'   => 45,
                'body'      => array(
                    'api_key'   => $api_key,
                    'form_id'   => $form_id,
                    'domain'    => $domain_name,
                ),
            ));

            //check if the API response is valid
            if (is_wp_error($response)){
                $error_messages = $response->get_error_message();
                set_transient('fmts_form_error_messages' .$contact_form_id, "Something went wrong: $error_messages", 30);
                return;
            }

            $response_body = wp_remote_retrieve_body($response);
            $data = json_decode($response_body, true);

            if (isset($data['message']) && $data['message'] === 'checked the form_id') {
                update_post_meta($contact_form->id(), 'formtoss_form_id', $form_id);
                delete_transient('fmts_form_error_messages' .$contact_form_id);
                set_transient('fmts_form_success_messages' .$contact_form_id, esc_html(fmts_get_translation('checked the form_id')), 30);
            } elseif (isset($data['message']) && $data['message'] === 'not found the form_id') {
                delete_transient('fmts_form_success_messages' .$contact_form_id);
                set_transient('fmts_form_error_messages' .$contact_form_id, esc_html(fmts_get_translation('not found the form_id')), 30);
            }elseif (isset($data['message']) && $data['message'] === 'Invalid API key') {
                delete_transient('fmts_form_success_messages' .$contact_form_id);
                set_transient('fmts_form_error_messages' .$contact_form_id, esc_html(fmts_get_translation('Invalid API key')), 30);
            }
        } else {
            set_transient('fmts_form_error_messages' .$contact_form_id, 'Form ID and API Key are required.', 30);
        }
        return "API Response: " . $data['message'];
    endif;
}
add_action('wpcf7_save_contact_form', 'fmts_save_form_id_hook_panel_data');