<?php
/*
 * Plugin Name: Form To SS
 * Plugin URI: https://formtoss.com/
 * Description: Simply post data from Contact form to spreadsheet
 * Version: 1.0.0
 * Requires at least: 6.3
 * Requires at PHP: 7.4
 * Author: Sakurabo
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html/
 * text Domain: form-to-ss
 */
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

define( 'FMTS_CF7_VERSION', '1.0.0' );
define( 'FMTS_CF7_PLUGIN', __FILE__ );
define( 'FMTS_CF7_PLUGIN_DIR', untrailingslashit( dirname( FMTS_CF7_PLUGIN ) ) );
define( 'FMTS_API_BASE_URL', 'https://formtoss.com/mypage');

// Include the common function file
require_once FMTS_CF7_PLUGIN_DIR . '/functions.php';
// Include the translations file
require_once FMTS_CF7_PLUGIN_DIR . '/translations.php';

require_once FMTS_CF7_PLUGIN_DIR . '/activation-formtoss.php';
require_once FMTS_CF7_PLUGIN_DIR . '/connect-formtoss.php';

//スクリプトの読み込み
function fmts_scripts_method($hook_suffix) {
    if ( true === fmts_strpos_array( $hook_suffix, ['toplevel', 'wpcf7-new'] ) ) {
        wp_enqueue_script( 'connectFormtoss', fmts_plugin_url('assets/connect-formtoss.js'), ['jquery'], FMTS_CF7_VERSION, true );

        // JavaScript に渡したいデータを定義
        $localized_data = array(
            'confirm_texts' => esc_js(fmts_get_translation('Are you sure to reset the Form ID')),
        );

        // `editButton` に対して `myData` というオブジェクトでデータを渡す
        wp_localize_script('connectFormtoss', 'myData', $localized_data);
    }
    elseif( true === fmts_strpos_array( $hook_suffix, ['formtoss-api-settings'] ) ) {
        wp_enqueue_script( 'activateFormtoss', fmts_plugin_url('assets/activation-formtoss.js'), ['jquery'], FMTS_CF7_VERSION, true );

        // JavaScript に渡したいデータを定義
        $localized_data = array(
            'confirm_texts' => esc_js(fmts_get_translation('Are you sure to reset the API key')),
        );

        // `editButton` に対して `myData` というオブジェクトでデータを渡す
        wp_localize_script('activateFormtoss', 'myData', $localized_data);
    }
    else {
        return;
    }
}
add_action( 'admin_enqueue_scripts', 'fmts_scripts_method' );

// send data to spreadsheet
function fmts_submit_to_spreadsheet($contact_form)
{
    $form_id = get_post_meta($contact_form->id(), 'formtoss_form_id', true);

    $api_key = get_option('formtoss_auth_key', true);

    if (!empty($form_id)) {
        // API end point
        $api_endpoint = FMTS_API_BASE_URL . '/api/add-to-G-sheet/' . urlencode($form_id);

        // Get submitted form data
        $submission = WPCF7_Submission::get_instance();
        $data_to_send = $submission->get_posted_data();

        // Iterate over each field to handle array data
        foreach ($data_to_send as $key => $value) {
            if (is_array($value)) {
                $data_to_send[$key] = implode(',' . PHP_EOL, $value);
            }
        }
        // Serialize the data
        $serialized_data = wp_json_encode($data_to_send);

        // Send data to the API endpoint
        $response = wp_remote_post($api_endpoint, array(
            'method' => 'POST',
            'body' => $serialized_data,
            'headers' => array(
                'auth' => $api_key,
                'Content-Type' => 'application/json',
                'Accept' => 'application/json',
            ),
            'timeout' => 45,
        ));

        if (!is_wp_error($response)) {
            $response_code = wp_remote_retrieve_response_code($response);
            $response_body = wp_remote_retrieve_body($response);
        } else {
            $error_messages = $response->get_error_message();
        }
    }
}
add_action('wpcf7_before_send_mail', 'fmts_submit_to_spreadsheet');


