<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

function fmts_strpos_array( $string = '', $needles=[] ){
    foreach( $needles as $needle ) {
        if( strpos( $string, $needle ) !== false ) {
            return true;
        }
    }

    return false;
}

/**
 * Returns the URL to a plugin file.
 *
 * @param string $path File path relative to the plugin root directory.
 * @return string URL.
 */
function fmts_plugin_url( $path = '' ) {
    $url = plugins_url( $path, FMTS_CF7_PLUGIN );

    if ( is_ssl() and 'http:' === substr( $url, 0, 5 ) ) {
        $url = 'https:' . substr( $url, 5 );
    }

    return $url;
}

/**
 * 任意のデータソースからテキスト値を取得し、サニタイズして返す関数
 *
 * @param array|ArrayAccess $source  データソース（例: $_POST や $_GET などの配列）
 * @param string|int        $key     取得したい値のキー名
 * @param string           $default デフォルト値（任意。未設定時は空文字列）
 * @return string サニタイズされたテキスト文字列
 */
function fmts_get_sanitized_text( $source, $key, $default = '' ) {
    // キーが存在するかチェック
    if ( isset( $source[$key] ) ) {
        // 存在すれば値を取得し、wp_unslashとsanitize_text_fieldでクリーンな文字列にして返す
        return sanitize_text_field( wp_unslash( $source[$key] ) );
    }
    // 存在しなければデフォルト値を返す
    return $default;
}


/**
 * HTTP_REFERER にリダイレクトする関数。
 * リファラーがない場合は指定されたフォールバックURLにリダイレクト。
 *
 * @param string $fallback_url リファラーがない場合の遷移先URL（デフォルト: home_url()）
 */
function fmts_redirect_to_referer_or( $fallback_url = '' ) {
    if ( isset( $_SERVER['HTTP_REFERER'] ) ) {
        wp_redirect( esc_url_raw( wp_unslash( $_SERVER['HTTP_REFERER'] ) ) );
    } else {
        $url = $fallback_url !== '' ? $fallback_url : home_url();
        wp_redirect( $url );
    }
    exit;
}